@@ -26,7 +26,7 @@ def main():
     parser.add_argument("-D", "--delete-them", help="Whenever a file is found with identical contents to a previously discovered file, delete the new one.  This option is dangerous.", action='store_true')
     parser.add_argument("-m", "--min-size", help="Ignore files smaller than this (default %d)." % DEFAULT_MINSIZE, default=DEFAULT_MINSIZE, type=int, metavar='M')
     parser.add_argument("-p", "--profiles", help="Generate a profile of your files which doesn't contain very much potentially-sensitive information (it contains only the file sizes rounded up to 4096 bytes, how many files were duplicates, and an 16-bit checksum of each file).  This could be useful for a p2p storage project to measure how valuable convergent encryption is.", default=DEFAULT_PROFILES, action='store_true')
-    parser.add_argument("dir", nargs='*', help="a directory to recursively examine", default=".")
+    parser.add_argument("dir", nargs='*', help="directories to recursively examine (default '.')", default=".")
     args = parser.parse_args()
 
     if args.delete_them and args.hard_link_them:
