@@ -28,14 +28,33 @@ def dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, DIRS):
 def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, DIRS, d1, next_multiple=mathutil.next_multiple):
     assert not (HARDLINKEM and DELETEEM) # at most one of these
 
+    visited = set() # to avoid symlink recursion
+
     # First pass: build map from size, dev, inode number to filenames.
-    def visit(dirpath, dirnames, fnames, next_multiple=next_multiple):
+    def visit(dirpath, dirnames, fnames, next_multiple=next_multiple, visited=visited):
+        assert os.path.isabs(dirpath), dirpath
+
+        dirstat = os.stat(dirpath)
+        dirdevino = dirstat[1:2]
+        if dirdevino in visited:
+            return
+        visited.add(dirdevino)
+
         for IGNOREDIR in IGNOREDIRS:
+            if os.path.isabs(IGNOREDIR):
+                if os.path.dirname(IGNOREDIR) == dirpath:
+                    if VERBOSITY > 2:
+                        print "ignoring %s because IGNOREDIR was %s and we are in %s" % (os.path.basename(IGNOREDIR), IGNOREDIR, dirpath)
+                    IGNOREDIR = os.path.basename(IGNOREDIR)
+                else:
+                    continue
             if IGNOREDIR in dirnames:
+                if VERBOSITY > 2:
+                    print "removing ignored dir %s from %s" % (IGNOREDIR, dirnames)
                 dirnames.remove(IGNOREDIR)
         for fname in fnames:
-            if VERBOSITY > 1:
-                print fname
+            if VERBOSITY > 2:
+                print "considering file: %s" % (os.path.join(dirpath, fname),)
             fullfname = os.path.join(dirpath, fname)
             try:
                 thestat = os.stat(fullfname)
@@ -55,14 +74,16 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, DIRS,
                     print "note: couldn't stat file named %s because %s" % (fullfname, le)
         for dirname in dirnames:
             if VERBOSITY > 2:
-                print "about to check islink(%s): %s" % (dirname, os.path.islink(dirname),)
-            if os.path.islink(dirname):
-                for (idirpath, idirnames, ifnames,) in os.walk(dirname):
+                print "about to check islink(%s): %s" % (os.path.join(dirpath, dirname), os.path.islink(os.path.join(dirpath, dirname)),)
+            if os.path.islink(os.path.join(dirpath, dirname)):
+                for (idirpath, idirnames, ifnames,) in os.walk(os.path.join(dirpath, dirname)):
                     visit(idirpath, idirnames, ifnames)
 
+    if VERBOSITY > 2:
+        print "about to visit DIRS %s" % (DIRS,)
     for DIR in DIRS:
         for (dirpath, dirnames, fnames,) in os.walk(DIR):
-            visit(dirpath, dirnames, fnames)
+            visit(os.path.abspath(dirpath), dirnames, fnames)
 
     # Second pass: for any files which have identical size and different (dev, ino,), md5 that file.  Build map from md5 to { (dev, ino,): [ fname ] }.
     # ... and print out any duplicates (that is: same md5, different (dev, ino,)).
@@ -70,12 +91,14 @@ def _dffem(VERBOSITY, IGNOREDIRS, HARDLINKEM, DELETEEM, MINSIZE, PROFILES, DIRS,
     for (sizestr, d2str,) in d1.iteritems():
         size = struct.unpack("@Q", sizestr)[0]
         d2 = loads(d2str)
+        if VERBOSITY > 2:
+            print "considering size class %d" % (size,)
         if (len(d2) > 1) or (len(d2) == 1 and PROFILES):
+            if (VERBOSITY > 2) or (VERBOSITY > 1 and len(d2) > 1):
+                print "about to compare %d elements of size class %d" % (len(d2), size)
             # d3 = { k: md5hash, v: { k: (dev, ino,), v: [ fname ] } }
             d3 = {}
 
-            if VERBOSITY:
-                print "files with same sizes.  size: %s, fnames: %s" % (size, d2,)
             for ((dev, ino,), fnames,) in d2.iteritems():
                 md5h = None
                 for fname in fnames:
